@@ -19,7 +19,7 @@ import boto3
 import hcl
 from github import Github
 
-__version__ = "0.12.2"
+__version__ = "0.13.0"
 
 DEFAULT_TERRAFORM_VARS = ".env/tf_env.json"
 DEFAULT_PROGRESS_INTERVAL = 10
@@ -365,7 +365,12 @@ def run_job(path, action):
         }
     :rtype: dict
     """
-    returncode, cout, cerr = execute(["make", "-C", path, action])
+    stdout = PIPE if action == "plan" else None
+    stderr = PIPE if action == "plan" else None
+
+    returncode, cout, cerr = execute(
+        ["make", "-C", path, action], stdout=stdout, stderr=stderr
+    )
     status = {"success": returncode == 0, "stderr": cerr, "stdout": cout}
     parse_tree = parse_plan(cout.decode("utf-8"))
     status["add"] = parse_tree[0]
